@@ -2,7 +2,18 @@ from __future__ import annotations
 
 import dataclasses
 import warnings
-from typing import TYPE_CHECKING, Any, List, Optional, Sequence, Tuple, Type, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from pydantic import BaseModel
 from pydantic.utils import lenient_issubclass
@@ -23,13 +34,13 @@ if TYPE_CHECKING:
     from pydantic.fields import ModelField
 
 
-def get_type_for_field(field: ModelField):
+def get_type_for_field(field: ModelField) -> Union[Any, Type[None], Type[List]]:
     type_ = field.outer_type_
     type_ = normalize_type(type_)
     return field_type_to_type(type_)
 
 
-def field_type_to_type(type_):
+def field_type_to_type(type_) -> Union[Any, List[Any], None]:
     error_class: Any = str
     strawberry_type: Any = error_class
 
@@ -59,7 +70,7 @@ def error_type(
     description: Optional[str] = None,
     directives: Optional[Sequence[object]] = (),
     all_fields: bool = False,
-):
+) -> Callable[..., Type]:
     def wrap(cls):
         model_fields = model.__fields__
         fields_set = set(fields) if fields else set()
@@ -68,6 +79,7 @@ def error_type(
             warnings.warn(
                 "`fields` is deprecated, use `auto` type annotations instead",
                 DeprecationWarning,
+                stacklevel=2,
             )
 
         existing_fields = getattr(cls, "__annotations__", {})
