@@ -1,5 +1,5 @@
 import inspect
-from typing import AsyncIterator, Awaitable, Iterator, TypeVar, Union
+from typing import AsyncIterator, Awaitable, Iterator, TypeVar, Union, cast
 
 T = TypeVar("T")
 
@@ -7,8 +7,8 @@ AwaitableOrValue = Union[Awaitable[T], T]
 AsyncIteratorOrIterator = Union[AsyncIterator[T], Iterator[T]]
 
 
-async def await_maybe(value: AwaitableOrValue):
+async def await_maybe(value: AwaitableOrValue[T]) -> T:
     if inspect.isawaitable(value):
         return await value
 
-    return value
+    return cast(T, value)
